@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.103_02';
+our $VERSION = '0.103_03';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Fri Aug 24 03:00:14 2018 GMT
+# on Sat Aug 25 17:44:14 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1729,7 +1729,7 @@ __PACKAGE__->status( add => 25077, iridium => '-', 'Iridium 42', 'Tumbling' );
 __PACKAGE__->status( add => 25078, iridium => '-', 'Iridium 44', 'Tumbling' );
 __PACKAGE__->status( add => 25104, iridium => '+', 'Iridium 45', '' );
 __PACKAGE__->status( add => 25105, iridium => '-', 'Iridium 24', 'Tumbling' );
-__PACKAGE__->status( add => 25106, iridium => 'S', 'Iridium 47', '' );
+__PACKAGE__->status( add => 25106, iridium => '-', 'Iridium 47', 'Tumbling' );
 __PACKAGE__->status( add => 25107, iridium => 'D', 'Iridium 48', 'Decayed 2001-05-05' );
 __PACKAGE__->status( add => 25108, iridium => 'D', 'Iridium 49', 'Decayed 2018-02-13' );
 __PACKAGE__->status( add => 25169, iridium => '+', 'Iridium 52', '' );
@@ -1780,13 +1780,13 @@ __PACKAGE__->status( add => 27374, iridium => 'D', 'Iridium 94', 'Decayed 2018-0
 __PACKAGE__->status( add => 27375, iridium => '+', 'Iridium 95', '' );
 __PACKAGE__->status( add => 27376, iridium => '-', 'Iridium 96', 'Tumbling' );
 __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
-__PACKAGE__->status( add => 27451, iridium => '-', 'Iridium 98', 'Tumbling' );
+__PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-08-24' );
 
 # Summary:
 # Operational [+]: 15
-#       Spare [S]: 14
+#       Spare [S]: 13
 #    Tumbling [-]: 37
-#     Decayed [D]: 31
+#     Decayed [D]: 32
 
 1;
 
